//
//  NodeBox.cpp
//  node_parent
//
//  Created by Reza Ghobadinic on 2019-03-18.
//

#include "NodeBox.h"
#include "NodeTriangle.h"

Node* NodeBox::createNode()
{
    return NodeBox::create();
}

bool NodeBox::init()
{
    if(!Node::init())
        return false;
    
    m_isDrawn = false;          // Make sure to draw once
    m_childKillerCounter = 0;
    
    // Creating four triangles
    auto triangle1 = NodeTriangle::create();
    auto triangle2 = NodeTriangle::create();
    auto triangle3 = NodeTriangle::create();
    auto triangle4 = NodeTriangle::create();
    
    // Position each triangle on the box's corners
    triangle1->setPosition(100, 100);
    triangle2->setPosition(100, -100);
    triangle3->setPosition(-100, 100);
    triangle4->setPosition(-100, -100);
    
    // Assigning the triangles as children with a tag
    addChild(triangle1, 0, 1); // child tagged 1
    addChild(triangle2, 0, 2); // child tagged 2
    addChild(triangle3, 0, 3); // child tagged 3
    addChild(triangle4, 0, 4); // child tagged 4
    
    auto rotate = RotateBy::create(3.0, 90.0);
    auto rotateReverse  = rotate->reverse();
    auto rotateSequence = Sequence::create(rotate, rotateReverse, nullptr);
    auto rotateRepeat   = RepeatForever::create(rotateSequence);
    
    auto scale = ScaleBy::create(3.0, 1.18);
    auto scaleReverse  = scale->reverse();
    auto scaleSequence = Sequence::create(scale, scaleReverse, nullptr);
    auto scaleRepeat   = RepeatForever::create(scaleSequence);
    
    auto delay = DelayTime::create(3.0f);
    std::function<void()> test = std::bind(&NodeBox::killNextChild, this);
    auto func  = CallFunc::create(test);
    auto funcSequence = Sequence::create(delay, func, nullptr);
    auto funcRepeat = Repeat::create(funcSequence, 4);
    
    runAction(scaleRepeat);
    runAction(rotateRepeat);
    runAction(funcRepeat);
    
    return true;
}

void NodeBox::killNextChild()
{
    // Keeps track of the tag number to remove
    m_childKillerCounter++;
    removeChildByTag(m_childKillerCounter);
}

void NodeBox::draw(Renderer* renderer, const Mat4& transform, uint32_t flags)
{
    if(!m_isDrawn)
    {
        auto draw = DrawNode::create();
        draw->drawLine(Vec2(-100, -100), Vec2(-100, +100), Color4F(1.0, 1.0, 1.0, 1.0));
        draw->drawLine(Vec2(+100, -100), Vec2(+100, +100), Color4F(1.0, 1.0, 1.0, 1.0));
        draw->drawLine(Vec2(-100, -100), Vec2(+100, -100), Color4F(1.0, 1.0, 1.0, 1.0));
        draw->drawLine(Vec2(-100, +100), Vec2(+100, +100), Color4F(1.0, 1.0, 1.0, 1.0));
        addChild(draw);
        m_isDrawn = true;
    }
}
