//
//  NodeTriangle.cpp
//  node_parent
//
//  Created by Reza Ghobadinic on 2019-03-18.
//

#include "NodeTriangle.h"

Node* NodeTriangle::createNode()
{
    return NodeTriangle::create();
}

bool NodeTriangle::init()
{
    if(!Node::init())
        return false;
    
    m_isDrawn = false;      // Make sure to draw once
    
    auto rotate = RotateBy::create(3.0, -90.0);
    auto rotateReverse  = rotate->reverse();
    auto rotateSequence = Sequence::create(rotate, rotateReverse, nullptr);
    auto rotateRepeat   = RepeatForever::create(rotateSequence);
    
    auto scale = ScaleBy::create(3.0, 1.8);
    auto scaleReverse  = scale->reverse();
    auto scaleSequence = Sequence::create(scale, scaleReverse, nullptr);
    auto scaleRepeat   = RepeatForever::create(scaleSequence);
    
    runAction(scaleRepeat);
    runAction(rotateRepeat);
    
    return true;
}

void NodeTriangle::draw(Renderer* renderer, const Mat4& transform, uint32_t flags)
{
    if(!m_isDrawn)
    {
        auto draw = DrawNode::create();
        // This is how the points values are calculated, if you are wondering:
        // float radius = 20.0;
        // Vec2 point1 = Vec2(radius * cos(90  * 3.1415 / 180), radius * sin(90  * 3.1415 / 180));
        // Vec2 point2 = Vec2(radius * cos(210 * 3.1415 / 180), radius * sin(210 * 3.1415 / 180));
        // Vec2 point3 = Vec2(radius * cos(330 * 3.1415 / 180), radius * sin(330 * 3.1415 / 180));
        Vec2 point1 = Vec2(0, 20);
        Vec2 point2 = Vec2(-17.3, -10);
        Vec2 point3 = Vec2(17.3, -10);
        draw->drawLine(point1, point2, Color4F(1.0, 1.0, 1.0, 1.0));
        draw->drawLine(point2, point3, Color4F(1.0, 1.0, 1.0, 1.0));
        draw->drawLine(point3, point1, Color4F(1.0, 1.0, 1.0, 1.0));
        addChild(draw);
        m_isDrawn = true;
    }
}
